@@ -93,7 +93,14 @@ void knetfilter::setupConnect() {
   KApplication::connect(&stop_mangle,SIGNAL(processExited(KProcess *)),
 			this,SLOT(stop_mangleDone()));  
   
-
+  KApplication::connect(&tcpmssrules,SIGNAL(processExited(KProcess *)),
+			this, SLOT(tcpmssRulesDone()));
+  KApplication::connect(&tcpmssrules,SIGNAL(receivedStdout(KProcess *, char *, int)),
+			this,SLOT(settcpmssRules(KProcess *, char *, int))); 
+  KApplication::connect(&tcpmssrules,SIGNAL(receivedStderr(KProcess *, char *, int)),
+			this,SLOT(settcpmssRules(KProcess *, char *, int))); 
+  //  Kapplication::connect(&stp_tcpmssrules,SIGNAL(processExited(KProcess *)),
+  //		this,SLOT(stop_tcpmssRulesDone()));
 
   KApplication::connect(&rules,SIGNAL(processExited(KProcess *)),
   			this,SLOT(listRulesDone()));
